% ajt.m.
%
% Written by Calum Iain Torrie 7/98
% input parameters of a triple pendulum
% refer to Appendix A

% TRIPLE PENDULUM MODEL WITH CANTILEVERS
% GLASGOW PROTOTYPE DECEMBER 98 
% all units are in S.I.


%***************

g	=9.81;

%********************************************************************

%upper mass from c:/accounts/calum/mofi2.pfe (for matlab)

m1	= 5.53;			%mass s/steel 'T' shape 
	
I1x	= 0.0474;
I1y	= 0.0081;
I1z	= 0.0465;

%********************************************************************
% masses and moments of inertia taken from c:/mydocuments/mofi.xls
%********************************************************************

ix	= 0.1;			%dimension of INTERMEDIATE MASS (AL cylinder)
ir	= 0.09;

m2	= 5.52;


I2x	= 0.02685;
I2y	= 0.01807;
I2z	= 0.01807;

%*********************************************************************

tx	= 0.1;			%dimensions of TEST MASS (AL cylinder)
tr	= 0.09;


m3	= 5.52;

I3x	= 0.02685;
I3y	= 0.01807;
I3z	= 0.01807;

%********************************************************************

l1	= 0.38;			%upper wire length
l2	= 0.185;		%intermediate wire length
l3	= 0.28;			%lower wire length

%******************************************************************************************

nw1	=2;			% number of wires per stage (2 or 4)
nw2	=4;
nw3	=4;

%***********************************************************************************

r1	=250e-6;	% radius of upper wire
r2	=175e-6;	% radius of intermediate wire 
r3	=140e-6;	% radius of lower wire

%************************************************************************************

Y1	=1.65e11;		% Youngs Modulus of upper wire	(s/steel 302)
Y2	=1.65e11;		% Youngs Modulus of intermediate wire (s/steel 302)
Y3	=1.65e11;		% Youngs Modulus of lower wire	(s/steel 302)

%**********************************************************************
%**********************************************************************

nc1	=2;			% number of cantilever blades per stage (2,4 or 0)
nc2	=4;
nc3	=0;

%*****************************************************************************

ufc1	=1.8;	% uncoupled mode frequency of cantilever stage(=0 for no cantilevers)
ufc2	=3;			 
ufc3	=0;

% NB:- uncoupled mode frequency- the frequency observed for a cantilever in a particular
%				 stage supporting only the mass of that stage 

%*****************************************************************************************

d0	= 0.001;	%height of upper wire break-off (above c.of m. upper mass)
d1	= 0.001;	%height of intermediate wire break-off (below c.of m. upper mass)
d2	= 0.001;	%height of intermediate wire break-off (above c.of m. of int. mass)
d3	= 0.001;	%height of lower wire break-off (below c.of m. intermediate mass)
d4	= 0.001;	%height of lower wire break-off (above c.of m.test mass)

%******************************************************************************************

% X direction separation

su	= 0.00;		% 1/2 separation of upper wires  
si	= 0.03;		% 1/2 separation of intermediate wires 
sl	= 0.005;	% 1/2 separation of lower wires 

%******************************************************************************************
	
% Y direction separation

n0	= 0.03;		% 1/2 separation of upper wires at suspension point
n1	= 0.04;		% 1/2 separation of upper wires at upper mass

n2	=0.045;		% 1/2 separation of intermediate wires at upper mass
n3	=ir+0.005;	% 1/2 separation of intermedite wires at intermediate mass

n4	=tr+0.01;	% 1/2 separation of lower wires at intermediate mass
n5	=tr+0.01;	% 1/2 separation of lower wires at test mass

%***********************************************************************************

% represents small loss

b1	= 0.03;b2=0.03;b3=0.03;b4=0.03; b5=0.03; b6=0.03;
%b1	= 0.00;b2=0.00;b3=0.00;b4=0.00; b5=0.00; b6=0.00;

%***********************************************************************************

% END OF INPUT

%******************************************************************************************
%******************************************************************************************
%******************************************************************************************

% CALCLULATIONS	

%***************************************************************

% spring constants

if (nc1==0)	
	kc1=0;				
else
	kc1	=  1/nc1 * (2*pi*ufc1)^2*m1;	% !check!
end
if (nc2==0)
	kc2=0;
else
	kc2	=  2/nc2 * (2*pi*ufc2)^2*m2;
end
if (nc3==0)
	kc3=0;
else
	kc3	=  2/nc3 * (2*pi*ufc3)^2*m3;	
end

kw1	=Y1*pi*r1^2/l1*nw1/2;	
kw2	=Y2*pi*r2^2/l2*nw2/2;	
kw3	=Y3*pi*r3^2/l3*nw3/2;	

if (kc1==0)
	k1=kw1;				
else
	k1=kc1*kw1/(kc1+kw1);
end
if (kc2==0)
	k2=kw2;
else
	k2=kc2*kw2/(kc2+kw2);
end
if (kc3==0)
	k3=kw3;
else
	k3=kc3*kw3/(kc3+kw3);
end

%********************************************************************

% allows choice of 2 wires to set separation to zero

if (nw1==2)
	s0=0;s1=0;
else
	s0=su;s1=su;
end
if (nw2==2)
	s2=0;s3=0;
else
	s2=si;s3=si;
end
if (nw3==2)
	s4=0;s5=0;
else
	s4=sl;s5=sl;
end

%********************************************************************

m13	= m1+m2+m3;m23	= m2+m3;

%***********************************************************************************

% cosine and sine of the angle the wire makes with the vertical (z)

si1=(n1-n0)/l1;			%sin(omega1)
si2=(n3-n2)/l2;			%sin(omega2)
si3=(n5-n4)/l3;			%sin(omega3)	
	
c1=(l1^2-(n1-n0)^2)^0.5/l1;	%cos(omega1)
c2=(l2^2-(n3-n2)^2)^0.5/l2;	%cos(omega2)
c3=(l3^2-(n5-n4)^2)^0.5/l3;	%cos(omega3)

%********************************************************
%***********************************************************************************

