% jbr.m.
%
% Written by Calum Iain Torrie 6/99
% input parameters of a triple pendulum

% TRIPLE PENDULUM MODEL WITH CANTILEVERS 
% all units are in S.I.

clear all

%***************

g	=9.81;

%********************************************************************

% Dummy upper mass!
ux	= 0.1;			%dimensions of UPPER MASS (square)
uy      = 0.3;
uz	= 0.07;
den1	= 2700;			%density (aluminium)

m1	= den1*uy*uz*ux;	%mass 

I1x	= m1*(uy^2+uz^2)/12;	%moment of inertia (sideways roll)
I1y	= m1*(uz^2+ux^2)/12;	%moment of inertia (longitudinal tilt)
I1z	= m1*(uy^2+ux^2)/12;	%moment of inertia (rotation)

%********************************************************************

ix	= 0.1;			%dimension of INTERMEDIATE MASS (cylinder)
ir	= 0.09;
den2	= 2202;			%density (fused silica)

m2	= den2*pi*ir^2*ix;	%intermediate mass

I2x	= m2*(ir^2/2);		%moment of inertia (sideways roll)
I2y	= m2*(ir^2/4+ix^2/12);	%moment of inertia (longitudinal tilt)
I2z	= m2*(ir^2/4+ix^2/12);	%moment of inertia (rotation)

%*********************************************************************

tx	= 0.1;			%dimensions of TEST MASS (cylinder)
tr	= 0.09;
den3	= 2202;			%density (fused silica)

m3	= den3*pi*tr^2*tx;	%test mass 

I3x	= m3*(tr^2/2);		%moment of inertia (sideways roll)
I3y	= m3*(tr^2/4+tx^2/12);	%moment of inertia (longitudinal tilt)
I3z	= m3*(tr^2/4+tx^2/12);	%moment of inertia (rotation)

%********************************************************************

l1	= 0.42;			%upper wire length
l2	= 0.187;		%intermediate wire length
l3	= 0.28;			%lower wire length

%******************************************************************************************

nw1	=2;			% number of wires per stage (2 or 4)
nw2	=4;			% = number of cantilevers (if fitted)
nw3	=4;

%***********************************************************************************

r1	=350e-6;	% radius of upper wire
r2	=175e-6;	% radius of intermediate wire 
r3	=154e-6;	% radius of lower wire


%************************************************************************************

Y1	=1.65e11;		% Youngs Modulus of upper wire	(s/steel 302)
Y2	=1.65e11;		% Youngs Modulus of intermediate wire (s/steel 302)
Y3	=7e10;			% Youngs Modulus of lower wire	(fused silica)

%**********************************************************************

ufc1	=2.6;	% uncoupled mode frequency of cantilever stage(=0 for no cantilevers)
ufc2	=3;			 
ufc3	=0;

% NB:- uncoupled mode frequency- the frequency observed for a cantilever in a particular
%				 stage supporting only the mass of that stage 

%*****************************************************************************************

d0	= 0.001;	%height of upper wire break-off (above c.of m. upper mass)
d1	= 0.001;	%height of intermediate wire break-off (below c.of m. upper mass)
d2	= 0.001;	%height of intermediate wire break-off (above c.of m. of int. mass)
d3	= 0.001;	%height of lower wire break-off (below c.of m. intermediate mass)
d4	= 0.001;	%height of lower wire break-off (above c.of m.test mass)

%******************************************************************************************

% X direction separation

su	= 0.00;		% 1/2 separation of upper wires  
si	= 0.03;		% 1/2 separation of intermediate wires 
sl	= 0.005;	% 1/2 separation of lower wires 

%******************************************************************************************
	
% Y direction separation

n0	= 0.03;		% 1/2 separation of upper wires at suspension point
n1	= 0.04;		% 1/2 separation of upper wires at upper mass


n2	=0.045;		% 1/2 separation of intermediate wires at upper mass
n3	=ir-0.0035+0.01;	% 1/2 separation of intermedite wires at intermediate mass


n4	=ir-0.0035+0.005;	% 1/2 separation of lower wires at intermediate mass
n5	=tr-0.0035+0.005;	% 1/2 separation of lower wires at test mass

%NB:- i.e. n4 = (radius) - (flat) + (break-off bar)

%***********************************************************************************

% local control units mechanical details

leverarmrt = 0.03; % half spacing of coils acting on tilt, rt
leverarmrz = 0.08; % half spacing of coils acting on rotation, rz
leverarmrl = 0.08; % half spacing of coils acting on roll, rl

%local control gains

gain = 0.4;

gainzrtrl = gain;	% vertical, z, tilt, rt, roll rl (coils on top of upper mass)
gaint   = gain.*2;	% sideways, t (coil on one end of upper mass)
gainlrz = gain;		% longitudinal, l, rotation, rz (coils on long rear side of upper mass) 

% represents small loss

b1	= 0.03;b2=0.03;b3=0.03;b4=0.03; b5=0.03; b6=0.03;

%***********************************************************************************

% END OF INPUT

%******************************************************************************************
%******************************************************************************************
%******************************************************************************************

% CALCLULATIONS	

%***************************************************************

% spring constants

kc1	=  1/2 * (2*pi*ufc1)^2*m1;
kc2	=  1/2 * (2*pi*ufc2)^2*m2;
kc3	=  1/2 * (2*pi*ufc3)^2*m3;	

kw1	=Y1*pi*r1^2/l1*nw1/2;	
kw2	=Y2*pi*r2^2/l2*nw2/2;	
kw3	=Y3*pi*r3^2/l3*nw3/2;	

if (kc1==0)
	k1=kw1;				
else
	k1=kc1*kw1/(kc1+kw1);
end
if (kc2==0)
	k2=kw2;
else
	k2=kc2*kw2/(kc2+kw2);
end
if (kc3==0)
	k3=kw3;
else
	k3=kc3*kw3/(kc3+kw3);
end

%********************************************************************

% in X-direction wires must be vertical

s0=su;s1=su;
s2=si;s3=si;
s4=sl;s5=sl;

%********************************************************************

m13	= m1+m2+m3;m23	= m2+m3;

%***********************************************************************************

% cosine and sine of the angle the wire makes with the vertical (z)

si1=(n1-n0)/l1;			%sin(omega1)
si2=(n3-n2)/l2;			%sin(omega2)
si3=(n5-n4)/l3;			%sin(omega3)	
	
c1=(l1^2-(n1-n0)^2)^0.5/l1;	%cos(omega1)
c2=(l2^2-(n3-n2)^2)^0.5/l2;	%cos(omega2)
c3=(l3^2-(n5-n4)^2)^0.5/l3;	%cos(omega3)

%********************************************************
%***********************************************************************************

