% generates 4 systems of state-space matices representing the triple pendulum
% defined in the file triplep.m which must be in the path
% see example_triplep.m for the definitions of the system_triplep
% (A, B, C and D matrix defintions)
% based on the mathematical model of Calum Iain Torrie et al. 1998
% function written by  K.A. Strain and Calum Iain Torrie 6/99
% version 0.5 - please do not edit without permission of the authors

% load in the pendulum parameters
triplep;

% general redefintion of variables to simplify notation
% and cope with different pendulum designs

kc1	=  1/2 * (2*pi*ufc1)^2*m1;	
kc2	=  1/2 * (2*pi*ufc2)^2*m2;

kw1	=Y1*pi*r1^2/l1*nw1/2;	
kw2	=Y2*pi*r2^2/l2*nw2/2;	
kw3	=Y3*pi*r3^2/l3*nw3/2;	

if (kc1==0)
	k1=kw1;				
else
	k1=kc1*kw1/(kc1+kw1);
end
if (kc2==0)
	k2=kw2;
else
	k2=kc2*kw2/(kc2+kw2);
end
	k3=kw3;

%********************************************************************

% allows choice of 2 wires to set separation to zero

s0=su;
s1=su;
s2=si;
s3=si;
s4=sl;
s5=sl;

%********************************************************************

m13	= m1+m2+m3;
m23	= m2+m3;

%***********************************************************************************

% cosine and sine of the angle the wire makes with the vertical (z)

si1=(n1-n0)/l1;			%sin(omega1)
si2=(n3-n2)/l2;			%sin(omega2)
si3=(n5-n4)/l3;			%sin(omega3)	
	
c1=(l1^2-(n1-n0)^2)^0.5/l1;	%cos(omega1)
c2=(l2^2-(n3-n2)^2)^0.5/l2;	%cos(omega2)
c3=(l3^2-(n5-n4)^2)^0.5/l3;	%cos(omega3)

%********************************************************

%longitudinal and pitch equations of motion 
%errors in some terms corrected 6/99
k11	= -m13*g*d0/I1y-2*k1*s0^2*c1^2/I1y-m23*g*d1/I1y-2*k2*s2^2*c2/I1y-m23*g*d1^2/I1y/l2/c2 ...
        -m13*g*d0^2/I1y/l1/c1-m13*g*s0^2*si1^2/I1y/l1/c1-m23*g*s2^2*si2^2/I1y/l2/c2;
k12	= -m23*g*d1/I1y/l2/c2+m13*g*d0/I1y/l1/c1;
k13	= -m23*g*d1*d2/I1y/l2/c2+2*k2*s2^2*c2^2/I1y+m23*g*s2^2*si2^2/l2/c2/I1y;
k14	= +m23*g*d1/I1y/l2/c2;
k15	= 0;
k16	= 0;

k21	= +m13*g*d0/m1/l1/c1-m23*g*d1/m1/l2/c2;
k22	= -m13*g/m1/l1/c1-m23*g/m1/l2/c2;
k23	= -m23*g*d2/m1/l2/c2;
k24	= +m23*g/m1/l2/c2;
k25	= 0;
k26	= 0;		

k31	= +2*k2*s2^2*c2^2/I2y-m23*g*d2*d1/I2y/l2/c2+m23*g*s2^2*si2^2/I2y/l2/c2;
k32	= -m23*g*d2/I2y/l2/c2 ;
k33	= -m23*g*d2/I2y-2*k2*s2^2*c2^2/I2y-m3*g*d3/I2y-2*k3*s4^2*c3^2/I2y-m23*g*d2^2/I2y/l2/c2 ...
        -m3*g*d3^2/I2y/l3/c3-m23*g*s2^2*si2^2/l2/I2y/c2-m3*g*s4^2*si3^2/l3/I2y/c3;
k34	= +m23*g*d2/I2y/l2/c2-m3*g*d3/I2y/l3/c3;
k35	= -m3*g*d3*d4/I2y/l3/c3+2*k3*s4^2*c3^2/I2y+m3*g*s4^2*si3^2/l3/I2y/c3;
k36	= +m3*g*d3/I2y/l3/c3;

k41	= +m23*g*d1/m2/l2/c2;
k42	= +m23*g/m2/l2/c2;
k43	= +m23*g*d2/m2/l2/c2-d3*m3*g/m2/l3/c3;
k44	= -m23*g/m2/l2/c2-m3*g/m2/l3/c3;
k45	= -m3*g*d4/m2/l3/c3;
k46	= +m3*g/m2/l3/c3;

k51	= 0;
k52	= 0;
k53	= +2*k3*s4^2*c3^2/I3y-m3*g*d4*d3/l3/I3y/c3+m3*g*s4^2*si3^2/I3y/l3/c3;
k54	= -m3*g*d4/I3y/l3/c3;
k55	= -m3*g*d4/I3y-2*k3*s4^2*c3^2/I3y-m3*g*d4^2/I3y/l3/c3-m3*g*s4^2*si3^2/I3y/l3/c3;
k56	= +m3*g*d4/I3y/l3/c3;

k61	= 0;
k62	= 0;
k63	= +g*d3/l3/c3;
k64	= +g/l3/c3;
k65	= +g*d4/l3/c3;
k66	= -g/l3/c3;

%********************************************************

%state space matrices pitch and longitudinal
% masses in descending order (top = 1, intermediate = 2, mirror = 3)
% angle/displacement angle/displacement angle/displacement 
% unphysical damping used to make open loop phase plots readable
% set b = 0 for closed loop plots
A=[0	0	0	0	0	0	1	0	0	0	0	0
   0	0	0	0	0	0	0	1	0	0	0	0			
   0	0	0	0	0	0	0	0	1	0	0	0
   0	0	0	0	0	0	0	0	0	1	0	0
   0	0	0	0	0	0	0	0	0	0	1	0
   0	0	0	0	0	0	0	0	0	0	0	1
    k11	k12	k13	k14	k15	k16	-bd	0	0	0	0	0
    k21	k22	k23	k24	k25	k26	0	-bd	0	0	0	0
    k31	k32	k33	k34	k35	k36	0	0	-bd	0	0	0
    k41	k42	k43	k44	k45	k46	0	0	0	-bd	0	0	
    k51  k52  	k53	k54	k55	k56	0	0	0	0	-bd	0
    k61	k62	k63	k64	k65	k66	0	0	0	0	0	-bd];

B=[0	0	0	0	0	0 -m13*g*d0/I1y/l1/c1 +m13*g/m1/l1/c1   0	0	0	0
   0	0	0	0	0	0	  0	1/m1	0	0	0	0 
   0	0	0	0	0	0	  0	1/m1	0	0	0	0 
   0  0  0  0  0  0    0  0	0	1/m2	0	0
   0	0	0	0	0	0	  0  0	0	0	0	1/m3 
   0  0  0  0  0  0  1/I1y 0   0		0	0	0
   0  0  0  0  0  0  1/I1y 0   0		0	0	0
   0  0  0  0  0  0    0  0  	1/I2y	0	0	0
   0  0  0  0  0  0    0  0	0	0 1/I3y 0
]';

C=[0	1	0	0	0	0	0	0	0	0	0	0
   0	0	0	1	0	0	0	0	0	0	0	0
   0	0	0	0	0	1	0	0	0	0	0	0
   1	0	0	0	0	0	0	0	0	0	0	0
   0	0	1	0	1	0	0	0	0	0	0	0
   0	0	0	0	1	0	0	0	0	0	0	0];

D=[-1  0  0  0  0  0  0  0 0
   0  0  0  0  0  0  0   0 0
   0  0  0  0  0  0  0   0 0
   0  0  0  -1  0  0  0  0 0 
   0  0  0  0  0  0  0   0 0
   0  0  0  0  0  0  0   0 0]; 

as = [0];
bs = [0];
cs = [0];
ds = [1];
leverarm           = lever_pitch;

[a,b,c,d]   = append(as,bs,cs,ds,as,bs,cs,ds);
[a,b,c,d]   = append(a,b,c,d,as,bs,cs,ds);
[a,b,c,d]   = append(a,b,c,d,as,bs,cs,ds);
[a,b,c,d]   = append(a,b,c,d,as,bs,cs,ds);
[a,b,c,d]   = append(a,b,c,d,as,bs,cs,2*lever_pitch);
[a,b,c,d]   = append(a,b,c,d,as,bs,cs,ds);
[a,b,c,d]   = append(a,b,c,d,as,bs,cs,ds);
[a,b,c,d]   = append(a,b,c,d,as,bs,cs,ds);
[alp,blp,clp,dlp]   = series(a,b,c,d,A,B,C,D);

lpn = ss(alp,blp,clp,dlp);
% yaw
AA	=m13*g/l1/c1*(s0^2*c1^2+n0*n1)+2*k1*s0^2*(n1-n0)^2/l1^2;
BB	=m23*g/l2/c2*(s2^2*c2^2+n2*n3)+2*k2*s2^2*(n3-n2)^2/l2^2;
CC	=m3*g/l3/c3*(s4^2*c3^2+n4*n5)+2*k3*s4^2*(n5-n4)^2/l3^2;
i11	=-AA/I1z-BB/I1z;
i12	=BB/I1z;
i21	=BB/I2z;
i22	=-BB/I2z-CC/I2z;
i23	=CC/I2z;
i32	=CC/I3z;
i33	=-CC/I3z;
ar=[	0	0	0	1	0	0
   	0	0	0	0	1	0
   	0	0	0	0	0	1
	   i11	i12	0	  -bd	0	 0
	   i21	i22	i23	0	-bd	 0
	   0	   i32	i33	0	 0	-bd];
br=[	0	0	0	AA/I1z 0	0
      0	0	0	1/I1z	 0	0
      0	0	0	1/I1z	 0	0
      0	0	0	0	1/I2z	0	
      0	0	0	0  0	1/I3z]';

cr=[	1	0	0	0	0	0
	   0	1	0	0	0	0
	   0	0	1	0	0	0];
dr=[-1 0 0 0 0
     0 0 0 0 0
     0 0 0 0 0];
[acr,bcr,ccr,dcr]   = append(as,bs,cs,ds,as,bs,cs,lever_yaw*2);
[acr,bcr,ccr,dcr]   =  append(acr,bcr,ccr,dcr,as,bs,cs,ds);
[acr,bcr,ccr,dcr]   =  append(acr,bcr,ccr,dcr,as,bs,cs,ds);
[acr,bcr,ccr,dcr]   =  append(acr,bcr,ccr,dcr,as,bs,cs,ds);
[ay,by,cy,dy]       = series(acr,bcr,ccr,dcr,ar,br,cr,dr);
yn = ss(ay,by,cy,dy);

% roll and transverse
j11	= -m13*g*d0/I1x+m13*g*n1*si1/I1x/c1-2*k1*n1^2/I1x-2*k1*n1*d0*si1/I1x/c1- ...
   m23*g*d1/I1x-m23*g*n2*si2/I1x/c2-2*k2*n2^2/I1x+2*k2*n2*d1*si2/I1x/c2+ ...
   m13*g*d0/I1x*(n1*si1/l1-d0*c1/l1)-m13*g*n1*si1/I1x/c1*(n1*si1/l1-d0*c1/l1)+ ...
   2*k1*l1*si1*n1/I1x*(n1*si1/l1-d0*c1/l1)+2*k1*l1*d0*si1^2/I1x/c1*(n1*si1/l1-d0*c1/l1)+ ...
   m23*g*d1/I1x*(-n2*si2/l2-d1*c2/l2)+m23*g*n2*si2/I1x/c2*(-n2*si2/l2-d1*c2/l2)- ...
   2*k2*l2*si2*n2/I1x*(-n2*si2/l2-d1*c2/l2)+2*k2*l2*d1*si2^2/I1x/c2*(-n2*si2/l2-d1*c2/l2);
j12	= -m23*g*d1*c2/I1x/l2-m23*g*n2*si2/I1x/l2+2*k2*si2*n2*c2/I1x-2*k2*d1*si2^2/I1x+ ...
   m13*g*d0*c1/I1x/l1-m13*g*n1*si1/I1x/l1+2*k1*si1*n1*c1/I1x+2*k1*d0*si1^2/I1x;
j13	= m23*g*d1/I1x*(n3*si2/l2-d2*c2/l2)+m23*n2*si2/I1x/c2*(n3*si2/l2-d2*c2/l2)- ...
   2*k2*l2*si2*n2/I1x*(n3*si2/l2-d2*c2/l2)+2*k2*l2*d1*si2^2/I1x/c2*(n3*si2/l2-d2*c2/l2)+ ...
   2*k2*n2*n3/I1x-2*k2*d1*si2*n3/I1x/c2;
j14	= +m23*g*d1*c2/I1x/l2+m23*g*n2*si2/I1x/l2-2*k2*si2*n2*c2/I1x+2*k2*d1*si2^2/I1x;
j15	= 0;
j16	= 0;

j21	= -m13*g/m1*(n1*si1/l1-d0*c1/l1)-2*k1*l1*si1^2/m1/c1*(n1*si1/l1-d0*c1/l1)+ ...
   2*k1*n1*si1/m1/c1+m23*g/m1*(-n2*si2/l2-d1*c2/l2)+2*k2*l2*si2^2/m1/c2*(-n2*si2/l2-d1*c2/l2)+ ...
   2*k2*n2*si2/m1/c2;
j22	= -m13*g*c1/m1/l1-m23*g*c2/m1/l2-2*k1*si1^2/m1-2*k2*si2^2/m1;
j23	= -2*k2*n3*si2/m1/c2+m23*g/m1*(n3*si2/l2-d2*c2/l2)+2*k2*l2*si2^2/m1/c2*(n3*si2/l2-d2*c2/l2);
j24	= +m23*g*c2/m1/l2+2*k2*si2^2/m1;
j25	= 0;
j26	= 0;		

j31	=+m23*g*d2/I2x*(-n2*si2/l2-d1*c2/l2)-m23*g*n3*si2/I2x/c2*(-n2*si2/l2-d1*c2/l2)+ ...
   2*k2*l2*si2*n3/I2x*(-n2*si2/l2-d1*c2/l2)+2*k2*l2*d2*si2^2/I2x/c2*(-n2*si2/l2-d1*c2/l2)+ ...
   2*k2*n2*n3/I2x+2*k2*d2*n2*si2/I2x/c2;
j32	= -(+m23*g*d2*c2/I2x/l2-m23*g*n3*si2/I2x/l2+2*k2*si2*n3*c2/I2x+2*k2*d2*si2^2/I2x);
j33	= +m23*g*d2/I2x*(n3*si2/l2-d2*c2/l2)-m23*g*n3*si2/I2x/c2*(n3*si2/l2-d2*c2/l2)+ ...
   2*k2*l2*si2*n3/I2x*(n3*si2/l2-d2*c2/l2)+2*k2*l2*d2*si2^2/I2x/c2*(n3*si2/l2-d2*c2/l2)- ...
   2*k2*n3*n3/I2x-2*k2*d2*n3*si2/I2x/c2-m23*g*d2/I2x+m23*g*n3*si2/I2x/c2+ ...
   m3*g*d3/I2x*(-n4*si3/l3-d3*c3/l3)+m3*g*n4*si3/I2x/c3*(-n4*si3/l3-d3*c3/l3)- ...
   2*k3*l3*si3*n4/I2x*(-n4*si3/l3-d3*c3/l3)+2*k3*l3*d3*si3^2/I3x/c3*(-n4*si3/l3-d3*c3/l3)- ...
   2*k3*n4*n4/I2x+2*k3*d3*n4*si3/I2x/c3-m3*g*d3/I2x-m3*g*n4*si3/I2x/c3;
j34	=-(+m3*g*d3*c3/I2x/l3+m3*g*n4*si3/I2x/l3-2*k3*si3*n4*c3/I2x+2*k3*d3*si3^2/I2x)+ ...
   m23*g*d2*c2/I2x/l2-m23*g*n3*si2/I2x/l2+2*k2*si2*n3*c2/I2x+2*k2*d2*si2^2/I2x;

j35	=+m3*g*d3/I2x*(n5*si3/l3-d4*c3/l3)+m3*g*n4*si3/I2x/c3*(n5*si3/l3-d4*c3/l3)- ...
   2*k3*l3*si3*n4/I2x*(n5*si3/l3-d4*c3/l3)+2*k3*l3*d3*si3^2/I2x/c3*(n5*si3/l3-d4*c3/l3)+ ...
   2*k3*n4*n5/I2x-2*k3*d3*n5*si3/I2x/c3;

j36	=+m3*g*d3*c3/I2x/l3+m3*g*n4*si3/I2x/l3-2*k3*si3*n4*c3/I2x+2*k3*d3*si3^2/I2x;


j41	= +m23*g*si2*n2/m2/l2/c2+m23*g*d1/m2/l2+2*k2*si2^3*n2/m2/c2+2*k2*si2^2*d1/m2-2*k2*n2*si2/m2/c2;
j42	= +m23*g*c2/m2/l2+2*k2*si2^2/m2;
j43	= -m23*g*n3*si2/m2/l2+m23*g*d2*c2/m2/l2-2*k2*l2*si2^2/m2/c2*(n3*si2/l2-d2*c2/l2)+ ...
   2*k2*n3*si2/m2/c2+2*k3*l3*si3^2/m2/c3*(-n4*si3/l3-d3*c3/l3)+m3*g/m2*(-n4*si3/l3-d3*c3/l3)+ ...
   2*k3*n4*si3/m2/c3;
j44	= -m23*g*c2/m2/l2-m3*g*c3/m2/l3-2*k2*si2^2/m2-2*k3*si3^2/m2;
j45	= -m3*g*d4*c3/m2/l3+m3*g*n5*si3/l3/m2-2*k3*n5*si3/m2/c3+2*k3*l3*si3^2/m2/c3*(n5*si3/l3-d4*c3/l3);
j46	= +m3*g*c3/m2/l3+2*k3*si3^2/m2;

j51	= 0;
j52	= 0;
j53	=+m3*g*d4/I3x*(-n4*si3/l3-d3*c3/l3)-m3*g*n5*si3/I3x/c3*(-n4*si3/l3-d3*c3/l3)+ ...
   2*k3*l3*si3*n5/I3x*(-n4*si3/l3-d3*c3/l3)+2*k3*l3*d4*si3^2/I3x/c3*(-n4*si3/l3-d3*c3/l3)+ ...
   2*k3*n5*n4/I3x+2*k3*d4*n4*si3/I3x/c3;
j54	= -(+m3*g*d4*c3/I3x/l3-m3*g*n5*si3/I3x/l3+2*k3*si3*n5*c3/I3x+2*k3*d4*si3^2/I3x);
j55	=-m3*g*d4/I3x+m3*g*n5*si3/I3x/c3+m3*g*d4/I3x*(n5*si3/l3-d4*c3/l3)- ...
   m3*g*n5*si3/I3x/c3*(n5*si3/l3-d4*c3/l3)+2*k3*l3*si3*n5/I3x*(n5*si3/l3-d4*c3/l3)+ ...
   2*k3*l3*d4*si3^2/I3x/c3*(n5*si3/l3-d4*c3/l3)-2*k3*n5^2/I3x-2*k3*d4*n5*si3/I3x/c3;
j56	= +m3*g*d4*c3/I3x/l3-m3*g*n5*si3/I3x/l3+2*k3*si3*n5*c3/I3x+2*k3*d4*si3^2/I3x;

j61	= 0;
j62	= 0;
j63	= -g*(-n4*si3/l3-d3*c3/l3)-2*k3*si3^2/m3/c3*(-n4*si3-d3*c3)-2*k3*n4*si3/m3/c3;
j64	= +g*c3/l3+2*k3*si3^2/m3;
j65	= -g*(n5*si3/l3-d4*c3/l3)-2*k3*si3^2/m3/c3*(n5*si3-d4*c3)+2*k3*n5*si3/m3/c3;
j66	= -g*c3/l3-2*k3*si3^2/m3;

% coordinates follow plan for pitch and yaw

A=[0	0	0	0	0	0	1	0	0	0	0	0
   0	0	0	0	0	0	0	1	0	0	0	0			
   0	0	0	0	0	0	0	0	1	0	0	0
   0	0	0	0	0	0	0	0	0	1	0	0
   0	0	0	0	0	0	0	0	0	0	1	0
   0	0	0	0	0	0	0	0	0	0	0	1
   j11	j12	j13	j14	j15	j16	-bd	0	0	0	0	0
   j21	j22	j23	j24	j25	j26	0	-bd	0	0	0	0
   j31	j32	j33	j34	j35	j36	0	0	-bd	0	0	0
   j41	j42	j43	j44	j45	j46	0	0	0	-bd	0	0	
   j51  j52  	j53	j54	j55	j56	0	0	0	0	-bd	0
   j61	j62	j63	j64	j65	j66	0	0	0	0	0	-bd];


B=[0	0	0	0	0	0 -m13*g*d0*c1/I1x/l1+m13*g*n1*si1/I1x/l1-2*k1*si1*n1*c1/I1x-2*k1*d0*si1^2/I1x +m13*g*c1/m1/l1+2*k1*si1^2/m1   0	0	0	0
   0	0	0	0	0	0     	0	1/m1	0	0	   0	0 
   0	0	0	0	0	0     	0	1/m1	0	0	   0	0 
   0  0  0  0  0  0       2*j11       0	0	0	0	0
   0  0  0  0  0  0       1/I1x       0	0	0	0	0
   0  0  0  0  0  0       1/I1x       0	0	0	0	0
]';


C=[0	1	0	0	0	0	0	0	0	0	0	0
   0	0	0	1	0  0	0	0	0	0	0	0
   0	0	0	0	0	1	0	0	0	0	0	0
   1	0	0	0	0	0	0	0	0	0	0	0
   0	0	1	0	0	0	0	0	0	0	0	0
   0	0	0	0	1	0	0	0	0	0	0	0];

D=[-1  0  0  0 0 0
    0  0  0  0 0 0
    0  0  0  0 0 0
   0  0  -1  0 0 0
   0  0  0   0 0 0
   0  0  0   0 0 0
   ];

[ac,bc,cc,dc]   = append(as,bs,cs,ds,as,bs,cs,ds);
[ac,bc,cc,dc]   = append(ac,bc,cc,dc,as,bs,cs,ds);
[ac,bc,cc,dc]   = append(ac,bc,cc,dc,as,bs,cs,3*lever_roll);
[ac,bc,cc,dc]   = append(ac,bc,cc,dc,as,bs,cs,ds);
[ac,bc,cc,dc]   = append(ac,bc,cc,dc,as,bs,cs,ds);
[art,brt,crt,drt]   = series(ac,bc,cc,dc,A,B,C,D);
rtn = ss(art,brt,crt,drt);

%vertical

h1=2*k1*c1^2+m13*g*si1^2/l1/c1;
h2=2*k2*c2^2+m23*g*si2^2/l2/c2;
h3=2*k3*c3^2+m3*g*si3^2/l3/c3;
h11 = - h1/m1 - h2 /m1;
h12 = h2/m1  ;
h21 = h2 / m2;
h22 = - h2 / m2 - h3 / m2;
h23 = h3 / m3 ;
h32 = h3 / m3;
h33 = - h3 / m3;

av= [ 	0	0 	0	1 	0	0	
         0	0	0	0	1	0	
	      0	0	0	0	0	1	
	    h11	h12	0  	-bd	0	0		
	   h21	h22	h23	0	-bd	0		
	   0	   h32	h33	0	0	-bd];

bv= [ 0	0	0  	h1 /m1  0   	 0	
      0	0	0	   1 / m1	0	   0
      0	0	0	   1 / m1	0	   0
     ]';

cv= [1	0	0	0	0	0	
	  0	1	0	0	0	0
	  0	0	1	0	0	0];
    
dv= [-1 0 0 
      0 0 0 
      0 0 0 ];

[acv,bcv,ccv,dcv]   = append(as,bs,cs,ds,as,bs,cs,3);
[acv,bcv,ccv,dcv]   = append(acv,bcv,ccv,dcv,as,bs,cs,ds);
[av,bv,cv,dv]   = series(acv,bcv,ccv,dcv,av,bv,cv,dv);
vn = ss(av,bv,cv,dv);

