% Written by Calum Iain Torrie 7/98 
% modified by K.A. Strain 6/99 version 0.5.1
% coordinates x = longitudinal = u_LIGO roll about this axis
%             y = transverse   = v_LIGO pitch about this axis
%             z = vertical     = w_LIGO yaw about this axis

% top mass is REPRESENTED by a rectangular BLOCK
% in reality it will be larger and less dense.
 g	=9.81;
 ux	= 0.10;			%dimensions of UPPER MASS (square)
 uy  =  0.17;
 uz	= 0.10;
 den1	= 7000;		%density (steel with holes)
 m1	= den1* uy* uz* ux;	%mass 
	
 I1x	=  m1*( uy^2+ uz^2)/12;	%moment of inertia (transverse roll)
 I1y	=  m1*( uz^2+ ux^2)/12;	%moment of inertia (longitudinal pitch)
 I1z	=  m1*( uy^2+ ux^2)/12;	%moment of inertia (yaw)
 pend.m1 = m1;
 pend.material1 = 'steel'
 pend.I1x = I1x;
 pend.I1y = I1y;
 pend.I1z = I1z;
 
%********************************************************************

 ix	= 0.10;			%dimension of INTERMEDIATE MASS (cylinder)
 ir	= 0.1325;
den2	= 2202;			%density (fused silica)
 m2	= den2*pi* ir^2* ix	;%intermediate mass
 I2x	= m2*(ir^2/2);		%moment of inertia (transverse roll)
 I2y	= m2*(ir^2/4+ix^2/12);	%moment of inertia (longitudinal pitch)
 I2z	= m2*(ir^2/4+ix^2/12);	%moment of inertia (yaw)
	
 pend.m2 = m2;
 pend.material2 = 'silica'
 pend.ix = ux;
 pend.ir = uy/2;
 pend.I2x = I2x;
 pend.I2y = I2y;
 pend.I2z = I2z;

%*********************************************************************

tx	= 0.10;			%dimensions of TEST MASS (cylinder)
tr	= 0.1325;
den3	= 2202;			%density (fused silica)

 m3	= den3*pi*tr^2*tx;	%test mass 

 I3x	= m3*(tr^2/2);		%moment of inertia (transverse roll)
 I3y	= m3*(tr^2/4+tx^2/12);	%moment of inertia (longitudinal pitch)
 I3z	= m3*(tr^2/4+tx^2/12);	%moment of inertia (yaw)
 pend.m3 = m3;
 pend.material2 = 'silica'
 pend.tx = tx;
 pend.tr = tr;
 pend.I3x = I3x;
 pend.I3y = I3y;
 pend.I3z = I3z;

%********************************************************************

 l1	= 0.25;			%upper wire length
 l2	= 0.20;		%intermediate wire length
 l3	= 0.21;			%lower wire length
pend.l1 = l1;
pend.l2 = l2;
pend.l3 = l3;
%******************************************************************************************

 nw1	=2;			% number of wires (= number of cantilevers if fitted) per stage (2 or 4)
 nw2	=4;
 nw3	=4;
pend.nw1 = nw1;
pend.nw2 = nw2;
pend.nw3 = nw3;
%***********************************************************************************

 r1	=605e-6;	% radius of upper wire
 r2	=402e-6;	% radius of intermediate wire 
 r3	=200e-6;	% radius of lower wire
pend.r1 = r1;
pend.r2 = r2;
pend.r3 = r3;
%************************************************************************************

 Y1	=1.65e11;		% Youngs Modulus of upper wire	(s/steel 302)
 Y2	=1.65e11;		% Youngs Modulus of intermediate wire (s/steel 302)
 Y3	=7e10;			% Youngs Modulus of lower wire	(fused silica)
pend.Y1 = Y1;
pend.Y2 = Y2;
pend.Y3 = Y3;
%**********************************************************************
%blade design - upper blades
 mntb = (m1 +m2 +m3)/2;%total per blade
 mnb  = m1/2;%uncoupled mass
 [uf,lnb,anb,hnb,stn] = opt(mnb,mntb,8e8,0.35,0.05);
 ufc1 = uf;
 pend.l1b = lnb;
 pend.a1b = anb;
 pend.h1b = hnb;
 pend.ufc1 = uf;
 pend.st1  = stn;
 pend.intmode_1 = 55*hnb*0.37^2/(0.002*lnb^2); %scaled from GEO blade

%blade design - lower blades
 mntb = (m2 +m3)/4;%total per blade
 mnb  = m2/4;%uncoupled mass
 [uf,lnb,anb,hnb,stn] = opt(mnb,mntb,8e8,0.20,0.05);
 ufc2 = uf;
 pend.l2b = lnb;
 pend.a2b = anb;
 pend.h2b = hnb;
 pend.ufc2 = uf;
 pend.st2  = stn;
 pend.intmode_2 = 55*hnb*0.37^2/(0.002*lnb^2); %scaled from GEO blade
 d0	= 0.001;	%height of upper wire break-off (above c.of m. upper mass)
 d1	= 0.001;	%height of intermediate wire break-off (below c.of m. upper mass)
 d2	= 0.001;	%height of intermediate wire break-off (above c.of m. of int. mass)
 d3	= 0.001;	%height of lower wire break-off (below c.of m. intermediate mass)
 d4	= 0.001;	%height of lower wire break-off (above c.of m.test mass)
 pend.di = 'all 0.001';
%******************************************************************************************

% X direction separation

 su	= 0.00;		% 1/2 separation of upper wires  
 si	= 0.04;		% 1/2 separation of intermediate wires 
 sl	= 0.015;	% 1/2 separation of lower wires 
 pend.su = su;
 pend.si = si;
 pend.sl = sl;
 %******************************************************************************************
	
% Y direction separation

 n0	= 0.13;		% 1/2 separation of upper wires at suspension point
 n1	= 0.06;		% 1/2 separation of upper wires at upper mass
 n2	= 0.04;		% 1/2 separation of intermediate wires at upper mass
 n3	=ir+0.0065;	% 1/2 separation of intermedite wires at intermediate mass
 n4	=tr+0.0015;	% 1/2 separation of lower wires at intermediate mass
 n5	=tr+0.0015;	% 1/2 separation of lower wires at test mass
 pend.n0 = n0;
 pend.n1 = n1;
 pend.n2 = n2;
 pend.n3 = n3;
 pend.n4 = n4;
 pend.n5 = n5;

%***********************************************************************************

% represents small loss

 bd = 0.01; % makes phases of open loop plots look nicer
lever_pitch = 0.04;
lever_roll	 = 0.09;
lever_yaw   = 0.1;
pend.lever_pitch=lever_pitch; 
pend.lever_roll=lever_roll; 
pend.lever_yaw=lever_yaw; 
pend 
