
% Uses code from Ken Strain 
% Calum I. Torrie November 2001
% Chris Cueva October 2006
% This program lists the pendulum parameters and mode frequencies.


clear all
global pend
format short g


ssmake2MBf;

[eigvec,eigval] = eig(mbdualA(13:24,1:12));
eigval=-diag(eigval);
[eigval,II] = sort(eigval,1,'descend');
eigvec = eigvec(:,II);
Hz = sqrt(eigval)/2/pi;

% Total number of coordinates
noofcoords = 12;

% List of coordinate indices
allcoords = 1:noofcoords;
nocoords = [];
% Lists of indices for specific groups of coordinates
longcoords = [1 7];
transcoords = [2 8];
vertcoords = [3 9];
yawcoords = [4 10];
pitchcoords = [5 11];
rollcoords = [6 12];
lpcoords = union(longcoords,pitchcoords);
trcoords = union(transcoords,rollcoords);
lptrcoords = union(lpcoords,trcoords);

% Vectors with 1's placed to pick out specific groups of coordinates
allcoordvec = ones([1 noofcoords]);
nocoordvec = zeros([1 noofcoords]);
longvec = nocoordvec; longvec(longcoords)=1;
transvec = nocoordvec; transvec(transcoords)=1;
vertvec = nocoordvec; vertvec(vertcoords)=1;
yawvec = nocoordvec; yawvec(yawcoords)=1;
pitchvec = nocoordvec; pitchvec(pitchcoords)=1;
rollvec = nocoordvec; rollvec(rollcoords)=1;
lpvec = nocoordvec; lpvec(lpcoords)=1;
trvec = nocoordvec; trvec(trcoords)=1;
lptrvec = nocoordvec; lptrvec(lptrcoords)=1;

% Number of "params" (Mathematica-model-speak for structure coordinates)
noofparams = 6;

% List of coordinate indices
allcoords = 1:noofcoords;
nocoords = [];
% Lists of indices for specific groups of params
longparams = [1];
transparams = [2];
vertparams = [3];
yawparams = [4];
pitchparams = [5];
rollparams = [6];
lpparams = union(longparams,pitchparams);
trparams = union(transparams,rollparams);
lptrparams = union(lpparams,trparams);

% "Square" of the eigenvectors, used for estimates of which coordinates are
% important
eigvec2 = eigvec.*eigvec;

% Measure of the participation of various groups of coordinates in the
% eigenvectors
vertprop = sum(eigvec2(vertcoords,:),1);
yawprop = sum(eigvec2(yawcoords,:),1);
lpprop = sum(eigvec2(lpcoords,:),1);
trprop = sum(eigvec2(trcoords,:),1);
vertprop1 = sum(abs(eigvec([3],:)),1);
yawprop1 = sum(abs(eigvec([4],:)),1);
lpprop1 = sum(abs(eigvec([1 5],:)),1);
trprop1 = sum(abs(eigvec([2 6],:)),1);

% Classification of eigenvectors: vert=1, yaw=2, lp=3, tr=4
[dummy, modetype] = max([vertprop;yawprop;lpprop;trprop],[],1);
[dummy, modetype1] = max([vertprop1;yawprop1;lpprop1;trprop1],[],1);

% Mode number lists for different types of modes
allmodes = allcoords;
nomodes = nocoords;
vertmodes = setdiff(union(allcoords.*(modetype==1),[]),[0]);
yawmodes = setdiff(union(allcoords.*(modetype==2),[]),[0]);
lpmodes = setdiff(union(allcoords.*(modetype==3),[]),[0]);
trmodes = setdiff(union(allcoords.*(modetype==4),[]),[0]);
lptrmodes = union(lpmodes,trmodes);
vertmodes1 = setdiff(union(allcoords.*(modetype1==1),[]),[0]);
yawmodes1 = setdiff(union(allcoords.*(modetype1==2),[]),[0]);
lpmodes1 = setdiff(union(allcoords.*(modetype1==3),[]),[0]);
trmodes1 = setdiff(union(allcoords.*(modetype1==4),[]),[0]);
lptrmodes1 = union(lpmodes1,trmodes1);

% Classification of modes based on sum of squares of different types of
% coordinates over all masses
longpitch = Hz(lpmodes)';
pend.longpitch1 = longpitch(1:min(length(lpmodes),2));
pend.longpitch2 = longpitch(min(length(lpmodes),2)+1:length(lpmodes));
pend.yaw       = Hz(yawmodes)';
transroll = Hz(trmodes)';
pend.transroll1 = transroll(1:min(length(trmodes),2));
pend.transroll2 = transroll(min(length(trmodes),2)+1:length(trmodes));
pend.vertical  = Hz(vertmodes)';

% Claissification of modes based on absolute value of coordinates at top
% mass
longpitchtop = Hz(lpmodes1)';
pend.longpitchtop1 = longpitchtop(1:min(length(lpmodes1),2));
pend.longpitchtop2 = longpitchtop(min(length(lpmodes1),2)+1:length(lpmodes1));
pend.yawtop       = Hz(yawmodes1)';
transrolltop = Hz(trmodes1)';
pend.transrolltop1 = transrolltop(1:min(length(trmodes1),2));
pend.transrolltop2 = transrolltop(min(length(trmodes1),2)+1:length(trmodes1));
pend.verticaltop  = Hz(vertmodes1)';

pend